==> libreoffice-24.8.5.2.tar.xz: libreoffice-24.8.5.2/connectivity/source/drivers/component/CColumns.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <component/CColumns.hxx>
#include <file/FTable.hxx>

using namespace connectivity::component;
using namespace connectivity;
using namespace ::com::sun::star::uno;


sdbcx::ObjectType OComponentColumns::createObject(const OUString& _rName)
{
    ::rtl::Reference<OSQLColumns> aCols = m_pTable->getTableColumns();

    OSQLColumns::const_iterator aIter = find(aCols->begin(),aCols->end(),_rName,::comphelper::UStringMixEqual(isCaseSensitive()));
    sdbcx::ObjectType xRet;
    if(aIter != aCols->end())
        xRet = sdbcx::ObjectType(*aIter,UNO_QUERY);
    return xRet;
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-25.8.2.2.tar.xz: libreoffice-25.8.2.2/connectivity/source/drivers/component/CColumns.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <component/CColumns.hxx>
#include <file/FTable.hxx>

using namespace connectivity::component;
using namespace connectivity;
using namespace ::com::sun::star::uno;


css::uno::Reference< css::beans::XPropertySet > OComponentColumns::createObject(const OUString& _rName)
{
    ::rtl::Reference<OSQLColumns> aCols = m_pTable->getTableColumns();

    OSQLColumns::const_iterator aIter = find(aCols->begin(),aCols->end(),_rName,::comphelper::UStringMixEqual(isCaseSensitive()));
    css::uno::Reference< css::beans::XPropertySet > xRet;
    if(aIter != aCols->end())
        xRet = *aIter;
    return xRet;
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
